EspIdfLogger

Struct EspIdfLogger 

pub struct EspIdfLogger<T = ()> { /* private fields */ }
A logger that integrates with the ESP-IDF logging system.

Specifically:

  • It logs to stdout/stderr just like the ESP-IDF native C logging functions
  • The format of the logs matches the ESP-IDF native C logging format
  • If the EspIdfLogFilter backend is used, it respects the ESP-IDF log level configuration

Implementations

Source

impl EspIdfLogger<EspIdfLogFilter>

pub fn initialize_default()

For backwards compatibility

Equivalent to calling init_from_esp_idf()

Source

impl<T> EspIdfLogger<T>

pub const fn new(filter: T) -> Self

Create a new instance of EspIdfLogger with the specified log filter backend.

Arguments
  • filter: The log filter backend to use for filtering log messages.
pub fn filter(&self) -> &T

Return a reference to the log filter backend used by this logger.