pub fn init(filter: LevelFilter) -> &'static EspIdfLogger<()>Expand description
Initialize the Rust logging system with the ESP-IDF logger and with the noop log filter backend (i.e. logging verbosity is controlled by the Rust log crate settings and disconnected from the ESP-IDF configuration settings).
Arguments:
filter: The log level filter to set in thelogcrate.